@@ -1,10 +1,10 @@
 # @package      hubzero-python
 # @file         webconfig.py
 # @author       David Benham <dbenham@purdue.edu>
-# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2015 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2015 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -113,7 +113,7 @@ def _writeParamField(componentOption, NewParamValueDictionary, hubName):
 
 	if hubzero.utilities.misc.JOOMLA_25:
 		parmString = json.dumps(NewParamValueDictionary)
-		sql = "UPDATE jos_extensions set params = %s WHERE type='component' AND `element` = %s"
+		sql = "UPDATE jos_extensions set params = %s WHERE type='component' AND `element` = %s AND client_id=1"
 	else:
 		parmString = ""
 		for parm in NewParamValueDictionary:
@@ -213,12 +213,15 @@ def _buildDictionary(componentOption, hubName):
 	
 	# look up parm string and parse it on newline, for each line, parse it further based on *first* '='
 	if hubzero.utilities.misc.JOOMLA_25:
-		sql = "SELECT `params` from jos_extensions WHERE type='component' AND `element`=%s"
+		sql = "SELECT `params` from jos_extensions WHERE type='component' AND `element`=%s AND client_id=1"
 	else:
 		sql = "SELECT `params` from jos_components WHERE `option`=%s"
 
 	data = (componentOption)
 	paramsString = db.query_selectscalar(sql, data)
+
+	if paramsString is None:
+		return {}
 	
 	if hubzero.utilities.misc.JOOMLA_25 and paramsString.startswith('{'):
 		try:
