@@ -1,10 +1,10 @@
 # @package      hubzero-python
 # @file         misc.py
 # @author       David Benham <dbenham@purdue.edu>
-# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2015 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2015 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -38,7 +38,7 @@ def isDebian():
 	
 def isRHEL():
 	distname, version, id = platform.linux_distribution(full_distribution_name=False)
-	return distname == 'redhat'
+	return distname == 'redhat' or distname == 'centos'
 
 
 def exShellCommand(argArray, processInput=''):
