@@ -251,19 +251,42 @@ def _insert_jos_xprofiles(db, hubname, uidNumber, fname, mname, lname, username,
 
 	pw = hashPassword(password)
 
-	sql = "INSERT INTO `jos_xprofiles` (`uidNumber`, `name`, `username`, `email`, `registerDate`, `gidNumber`, `homeDirectory`, `loginShell`, "
-	sql += "`ftpShell`, `userPassword`, `gid`, `orgtype`, `organization`, `countryresident`, `countryorigin`, `gender`, `url`, `reason`, "
-	sql += "`mailPreferenceOption`, `usageAgreement`, `jobsAllowed`, `modifiedDate`, `emailConfirmed`, `regIP`, `regHost`, `nativeTribe`, `phone`, "
-	sql += "`proxyPassword`, `proxyUidNumber`, `givenName`, `middleName`, `surname`, `picture`, `vip`, `public`, `params`, `note`, `shadowExpire`) "
-	sql += "VALUES (" + '%s,'*37 + "%s );" 
+	# have to support multiple database schemas for this query
+	sql = "SELECT count(1) FROM information_schema.COLUMNS WHERE TABLE_NAME = 'jos_xprofiles' AND COLUMN_NAME = 'jobsAllowed'"
+	rowCount = db.query_selectscalar(sql, None)
 
-	# this is a hack, @TODO: something less hackish would be good here
+	#cursor.execute(sql)
+	##rs = cursor.fetchone()
+
+	# this is a hack, @TODO: something less hackish would be good here. Not sure why I did this, datatype issue?
 	tou = 1
 
-	data = (uidNumber, fname + ' ' + lname, username, email, datetime.datetime.now(), gidNumber, homeDir, loginShell, 
-		    '/usr/lib/sftp-server', pw, gid, '', '', '', '', '', '', '', 
-		    0, tou, 3, '0000-00-00 00:00:00', 1, '', '', '', '',
-		    '', '', fname, mname, lname, '', 0, 0, '', '', None)
+	# newer table version requires different insert (so far jobsAllowed is the only exception)
+	if rowCount == 1:
+		sql = "INSERT INTO `jos_xprofiles` (`uidNumber`, `name`, `username`, `email`, `registerDate`, `gidNumber`, `homeDirectory`, `loginShell`, "
+		sql += "`ftpShell`, `userPassword`, `gid`, `orgtype`, `organization`, `countryresident`, `countryorigin`, `gender`, `url`, `reason`, "
+		sql += "`mailPreferenceOption`, `usageAgreement`, , `jobsAllowed`, `modifiedDate`, `emailConfirmed`, `regIP`, `regHost`, `nativeTribe`, `phone`, "
+		sql += "`proxyPassword`, `proxyUidNumber`, `givenName`, `middleName`, `surname`, `picture`, `vip`, `public`, `params`, `note`, `shadowExpire`) "
+		sql += "VALUES (" + '%s,'*37 + "%s );" 
+
+		data = (uidNumber, fname + ' ' + lname, username, email, datetime.datetime.now(), gidNumber, homeDir, loginShell, 
+			    '/usr/lib/sftp-server', pw, gid, '', '', '', '', '', '', '', 
+			    0, tou, 3, '0000-00-00 00:00:00', 1, '', '', '', '',
+			    '', '', fname, mname, lname, '', 0, 0, '', '', None)
+
+	else:
+		sql = "INSERT INTO `jos_xprofiles` (`uidNumber`, `name`, `username`, `email`, `registerDate`, `gidNumber`, `homeDirectory`, `loginShell`, "
+		sql += "`ftpShell`, `userPassword`, `gid`, `orgtype`, `organization`, `countryresident`, `countryorigin`, `gender`, `url`, `reason`, "
+		sql += "`mailPreferenceOption`, `usageAgreement`, `modifiedDate`, `emailConfirmed`, `regIP`, `regHost`, `nativeTribe`, `phone`, "
+		sql += "`proxyPassword`, `proxyUidNumber`, `givenName`, `middleName`, `surname`, `picture`, `vip`, `public`, `params`, `note`, `shadowExpire`) "
+		sql += "VALUES (" + '%s,'*36 + "%s );" 
+
+
+		data = (uidNumber, fname + ' ' + lname, username, email, datetime.datetime.now(), gidNumber, homeDir, loginShell, 
+			    '/usr/lib/sftp-server', pw, gid, '', '', '', '', '', '', '', 
+			    0, tou, '0000-00-00 00:00:00', 1, '', '', '', '',
+			    '', '', fname, mname, lname, '', 0, 0, '', '', None)
+
 	db.query_rowcount(sql, data)
 
 
@@ -353,7 +376,7 @@ def addhubuser(hubname,
                loginShell = "/bin/bash", 
                skipCreateHome = False, 
                homeDir = "", 
-               skipCreateGroup = False, 
+               createGroup = False, 
                skipCreateLDAPUser = False, 
                skipCreateCMSUser = False, 
                uid_min = 1000, 
@@ -373,7 +396,7 @@ def addhubuser(hubname,
 	loginShell - user's login shell
 	skipCreateHome - skip creating user's home directory
 	homeDir - path to user's home directory
-	skipCreateGroup - skip creating a default group for new user, group name matches the username
+	createGroup - skip creating a default group for new user, group name matches the username
 	skipCreateLDAPUser - skip creating ldap info for this user
 	skipCreateCMSUser - skip ldap info for this user
 	"""
@@ -432,7 +455,7 @@ def addhubuser(hubname,
 		return(3)
 
 	# if the user doesn't want custom group for this user, they still need to be added to some group
-	if skipCreateGroup:
+	if not createGroup:
 		gidNumber = 100 # default to the users group
 		gid = 'users'
 
@@ -440,7 +463,7 @@ def addhubuser(hubname,
 		# create group for user named same as username (need group insert here for xprofiles addition below)
 		# Guess if user specifies a specific already created group for the new user and says create a new group for the 
 		# user, we'll override and create the new group with this logic
-		if not skipCreateGroup:
+		if createGroup:
 			gidNumber = hubzero.utilities.group._insert_jos_xgroups(db, username, username + " group", grouptype)	
 			gid = username # group name same as user
 
@@ -459,7 +482,7 @@ def addhubuser(hubname,
 		_insert_jos_users_password(db, uidNumber, pw)
 
 		# add user to new group (need xgroups insert after user creation because we need userid, I'd prefer to keep all group logic in one place)
-		if not skipCreateGroup:
+		if createGroup:
 			hubzero.utilities.group._insert_jos_xgroups_members(db, gidNumber, uidNumber)
 
 		# create home directory
@@ -471,7 +494,7 @@ def addhubuser(hubname,
 			print "creating homedir: " + homeDir
 
 			# set ownership
-			if not skipCreateGroup:
+			if createGroup:
 				os.chown(homeDir, uidNumber, gidNumber)
 			else:
 				os.chown(homeDir, uidNumber, -1)
@@ -487,7 +510,7 @@ def addhubuser(hubname,
 		if uidNumber == -1:
 			uidNumber = hubzero.utilities.user.getLDAPMinUIDNumber(hubname, uid_min, uid_max)
 
-		if not skipCreateGroup:
+		if not createGroup:
 			hubzero.utilities.group.add_ldap_group(username, username + " group", gidNumber)
 
 		add_ldap_user(username, gecos, pw, uidNumber, homeDir, loginShell, gid, gidNumber)
